@@ -65,7 +65,7 @@ if ( !$slewtarget ){
 
 #change to IP if across network
 initSX('localhost');
-#initSX('192.168.3.96');
+#initSX('192.168.3.12');
 
 ####################################################################
 # This tests the raw Send/Get methods to send raw java script      #
@@ -101,17 +101,7 @@ testsky6ObjectInformation("$slewtarget");
 
 # Query will run, but unsure how to access the results.
 
-testsky6DataWizard("Planet report.dbq");
-
-####################################################################
-# Tests for Astro::SkyX::sky6DirectGuide module.                    #
-####################################################################
-
-if ( $movetests ) {
-  testsky6DirectGuide();
-}else{
-  print "sky6DirectGuide not tested because of potential telescope movement.\n";
-}
+testsky6DataWizard("Objects on Virtual Sky.dbq");
 
 ####################################################################
 # Tests for Astro::SkyX::sky6MyFOVs module.                        #
@@ -138,6 +128,16 @@ if ( $movetests ) {
   print "sky6RASCOMTele  not tested because of potential telescope movement.\n";
 }
 
+####################################################################
+# Tests for Astro::SkyX::sky6DirectGuide module.                    #
+####################################################################
+
+if ( $movetests ) {
+  testsky6DirectGuide();
+}else{
+  print "sky6DirectGuide not tested because of potential telescope movement.\n";
+}
+
 ####################################################################
 # Tests for Astro::SkyX::sky6Web module.                           #
 ####################################################################
@@ -166,7 +166,7 @@ testccdsoftCamera();
 # testImageLink(pathtoFITS,imagescale,unknownscale)
 my $DSSimage = $SX->ccdsoftCamera->LastImageFileName;
 #testImageLink($DSSimage,1.70,1); 
-#testImageLink('C:\Users\Woody\Desktop\test.fits',1.50,1); 
+testImageLink('C:\Users\Woody\Desktop\test.fit',.47,1); 
 # testImageLink('/Users/woody/Desktop/test.fits',1.48,0); # Mac OSX
 
 ####################################################################
