@@ -7,8 +7,13 @@ require IO::Socket;
 require Scalar::Util;
 require Exporter;
 require Astro::SkyX::Application;
-require Astro::SkyX::ImageLink;
+require Astro::SkyX::AutomatedImageLinkSettings;
+require Astro::SkyX::ClosedLoopSlew;
 require Astro::SkyX::ImageLinkResults;
+require Astro::SkyX::ImageLink;
+require Astro::SkyX::OpticalTubeAssembly;
+require Astro::SkyX::SelectedHardware;
+require Astro::SkyX::WeatherUtil;
 require Astro::SkyX::TheSkyXAction;
 require Astro::SkyX::ccdsoftCamera;
 require Astro::SkyX::ccdsoftCameraImage;
@@ -39,7 +44,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = '0.07';
+our $VERSION = '0.11';
  
  my %attr_data = 
      (
@@ -56,33 +61,43 @@ our $VERSION = '0.07';
 
     my $self = bless {
         _debug          => $arg{"DEBUG"},
-        _SkyXConnection => $_[2],
-	_connect	=> $_[3],
-	_Send		=> $_[4],
-	_Get		=> $_[5],
-        _Application	=> $_[6],
-        _ImageLink	=> $_[7],
-        _ImageLinkResults	=> $_[8],
-        _TheSkyXAction	=> $_[9],
-        _sky6DataWizard	=> $_[10],
-        _sky6DirectGuide	=> $_[11],
-        _sky6Dome	=> $_[12],
-        _sky6MyFOVs	=> $_[13],
-        _sky6ObjectInformation	=> $_[14],
-        _sky6RASCOMTele	=> $_[15],
-        _sky6RASCOMTheSky	=> $_[16],
-        _sky6Raven	=> $_[17],
-        _sky6StarChart	=> $_[18],
-        _sky6TheSky	=> $_[19],
-        _sky6Utils	=> $_[20],
-        _sky6Web	=> $_[21],
-        _ccdsoftCamera  => $_[22],
-        _ccdsoftCameraImage   => $_[23],
-        _ccdsoftAutoguiderImage   => $_[24],
+        _SkyXConnection			=> $_[2],
+	_connect			=> $_[3],
+	_Send				=> $_[4],
+	_Get				=> $_[5],
+        _Application			=> $_[6],
+	_AutomatedImageLinkSettings	=> $_[7],
+	_ClosedLoopSlew			=> $_[8],
+        _ImageLinkResults		=> $_[9],
+        _ImageLink			=> $_[10],
+	_OpticalTubeAssembly		=> $_[11],
+	_SelectedHardware		=> $_[12],
+	_WeatherUtil			=> $_[13],
+        _TheSkyXAction			=> $_[14],
+        _sky6DataWizard			=> $_[15],
+        _sky6DirectGuide		=> $_[16],
+        _sky6Dome			=> $_[17],
+        _sky6MyFOVs			=> $_[18],
+        _sky6ObjectInformation		=> $_[19],
+        _sky6RASCOMTele			=> $_[20],
+        _sky6RASCOMTheSky		=> $_[21],
+        _sky6Raven			=> $_[22],
+        _sky6StarChart			=> $_[23],
+        _sky6TheSky			=> $_[24],
+        _sky6Utils			=> $_[25],
+        _sky6Web			=> $_[26],
+        _ccdsoftCamera  		=> $_[27],
+        _ccdsoftCameraImage   		=> $_[28],
+        _ccdsoftAutoguiderImage   	=> $_[29],
 	}, $class;
     $self->{_Application} = Astro::SkyX::Application::new("Astro::SkyX::Application");
-    $self->{_ImageLink} = Astro::SkyX::ImageLink::new("Astro::SkyX::ImageLink");
+    $self->{_AutomatedImageLinkSettings} = Astro::SkyX::AutomatedImageLinkSettings::new("Astro::SkyX::AutomatedImageLinkSettings");
+    $self->{_ClosedLoopSlew} = Astro::SkyX::ClosedLoopSlew::new("Astro::SkyX::ClosedLoopSlew");
     $self->{_ImageLinkResults} = Astro::SkyX::ImageLinkResults::new("Astro::SkyX::ImageLinkResults");
+    $self->{_ImageLink} = Astro::SkyX::ImageLink::new("Astro::SkyX::ImageLink");
+    $self->{_OpticalTubeAssembly} = Astro::SkyX::OpticalTubeAssembly::new("Astro::SkyX::OpticalTubeAssembly");
+    $self->{_SelectedHardware} = Astro::SkyX::SelectedHardware::new("Astro::SkyX::SelectedHardware");
+    $self->{_WeatherUtil} = Astro::SkyX::WeatherUtil::new("Astro::SkyX::WeatherUtil");
     $self->{_TheSkyXAction} = Astro::SkyX::TheSkyXAction::new("Astro::SkyX::TheSkyXAction");
     $self->{_sky6DataWizard} = Astro::SkyX::sky6DataWizard::new("Astro::SkyX::sky6DataWizard");
     $self->{_sky6DirectGuide} = Astro::SkyX::sky6DirectGuide::new("Astro::SkyX::sky6DirectGuide");
@@ -106,18 +121,47 @@ our $VERSION = '0.07';
     my $self = shift @_;
     return $self->{_Application};
   }
-  sub ImageLink {
+
+  sub AutomatedImageLinkSettings {
     my $self = shift @_;
-    return $self->{_ImageLink};
+    return $self->{_AutomatedImageLinkSettings};
   }
+
+  sub ClosedLoopSlew {
+    my $self = shift @_;
+    return $self->{_ClosedLoopSlew};
+  }
+
   sub ImageLinkResults {
     my $self = shift @_;
     return $self->{_ImageLinkResults};
   }
+
+  sub ImageLink {
+    my $self = shift @_;
+    return $self->{_ImageLink};
+  }
+
+  sub OpticalTubeAssembly {
+    my $self = shift @_;
+    return $self->{_OpticalTubeAssembly};
+  }
+
+  sub SelectedHardware {
+    my $self = shift @_;
+    return $self->{_SelectedHardware};
+  }
+
+  sub WeatherUtil {
+    my $self = shift @_;
+    return $self->{_WeatherUtil};
+  }
+
   sub TheSkyXAction {
     my $self = shift @_;
     return $self->{_TheSkyXAction};
   }
+
   sub sky6DataWizard {
     my $self = shift @_;
     return $self->{_sky6DataWizard};
@@ -326,16 +370,18 @@ None by default.
 
 =head1 SEE ALSO
 
- There is class specific documentation for any odd things that had to
+There is class specific documentation for any odd things that had to
 be kludged. perldoc Astro::SkyX::Classname to see it.
 
+Don't forget ScriptTheSkyX documentation from Software Bisque.
+
 =head1 AUTHOR
 
 Robert Woodard, E<lt>kayak.man@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Robert Woodard
+Copyright (C) 2015 by Robert Woodard
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.3 or,
