@@ -26,9 +26,8 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = '0.03';
-our @PROPERTIES = qw(  );
-our @READWRITEPROPS = qw(  );
+our $VERSION = '0.11';
+our @FUNCTIONS = qw(  );
 
 # Preloaded methods go here.
 
@@ -45,8 +44,6 @@ our @READWRITEPROPS = qw(  );
 #    $self->_incr_count();
     return $self;
   }
-#    sub _incr_count { ++$_count }
-#    sub _decr_count { --$_count }
 
  sub AUTOLOAD ($;$) {
     no strict "refs";
@@ -56,14 +53,13 @@ our @READWRITEPROPS = qw(  );
     if ($AUTOLOAD =~ /.*::(.*::.*)/) {
       my $method = $1;
       # Let's build the javascript
-#      $newtext = join ',', map{ qq/"$_"/ }@newval;
       $newtext = join ',', map{ /^[0-9.-]*$/ ? $_ : qq/'$_'/ }@newval;
       $method =~ tr/::/./s;
 
       my ($package, $propertyName) = $AUTOLOAD =~ m/^(.+::)(.+)$/;
-      if(haveProperty($propertyName)){
+      if(haveFunction($propertyName)){
         $js .= $method . "(" . $newtext . ");\r\n";
-      } elsif(haveReadWriteProp($propertyName) and length($newtext) ){
+      } elsif(length($propertyName) and length($newtext) ){
         $js .= $method . ' = ' . $newtext . ";\r\n";
       } else {
         $js .= $method . ";\r\n";
@@ -74,20 +70,10 @@ our @READWRITEPROPS = qw(  );
     die "No such method: $AUTOLOAD";
  }
 
- sub haveReadWriteProp{
+ sub haveFunction{
         my ($value) = @_;
-        for my $property (@READWRITEPROPS){
-                if($property eq $value){
-                        return "1";
-                }
-        }
-        return undef;
- }
-
- sub haveProperty{
-        my ($value) = @_;
-        for my $property (@PROPERTIES){
-                if($property eq $value){
+        for my $function (@FUNCTIONS){
+                if($function eq $value){
                         return "1";
                 }
         }
@@ -108,33 +94,31 @@ SkyX - Perl extension for communications with The SkyX Professional Version 10.2
 
 =head1 SYNOPSIS
 
-  use SkyX;
-  blah blah blah
+  use Astro::SkyX;
+  my $SX = Astro::SkyX->new();
+  $Skysock = $SX->connect('localhost','3040');
+
+  print "\nSkyX Initialized status: ",
+    $SX->Application->initialized,
+    "\nRunning version: ",
+    $SX->Application->version,
+    " Build " . $SX->Application->build,
+    " on OS: " . $SX->Application->operatingSystem,
+    "\n";
+
 
 =head1 DESCRIPTION
 
-Stub documentation for SkyX, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
+Implementation of the SkyX Application Class.
 
 =head2 EXPORT
 
 None by default.
 
 
-
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+Don't forget ScriptTheSkyX documentation from Software Bisque.
 
 =head1 AUTHOR
 
@@ -148,5 +132,8 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.3 or,
 at your option, any later version of Perl 5 you may have available.
 
+There are restrictions on commercial use of the SkyX scripting engine.
+Please see the Software Bisque End User License Agreement prior to
+using this module in a commercial setting.
 
 =cut
