@@ -26,10 +26,8 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = '0.03';
-our @PROPERTIES = qw(  );
-our @READWRITEPROPS = qw( );
-#our @READPROPS = qw( imageScale errorText imageFilePath );
+our $VERSION = '0.11';
+our @FUNCTIONS = qw(  );
 
 # Preloaded methods go here.
 
@@ -47,8 +45,6 @@ our @READWRITEPROPS = qw( );
 #    $self->_incr_count();
     return $self;
   }
-#    sub _incr_count { ++$_count }
-#    sub _decr_count { --$_count }
 
   sub AUTOLOAD ($;$) {
     no strict "refs";
@@ -58,15 +54,13 @@ our @READWRITEPROPS = qw( );
     if ($AUTOLOAD =~ /.*::(.*::.*)/) {
       my $method = $1;
       # Let's build the javascript
-#      $newtext = join ',', map{ qq/"$_"/ }@newval;
       $newtext = join ',', map{ /^[0-9.-]*$/ ? $_ : qq/'$_'/ }@newval;
       $method =~ tr/::/./s;
 
       my ($package, $propertyName) = $AUTOLOAD =~ m/^(.+::)(.+)$/;
-      if(haveProperty($propertyName)){
+      if(haveFunction($propertyName)){
         $js .= $method . "(" . $newtext . ");\r\n";
-      } elsif(haveReadWriteProp($propertyName) and length($newtext) ){
-
+      } elsif(length($propertyName) and length($newtext) ){
         $js .= $method . ' = ' . $newtext . ";\r\n";
       } else {
         $js .= $method . ";\r\n";
@@ -77,20 +71,10 @@ our @READWRITEPROPS = qw( );
     die "No such method: $AUTOLOAD";
   }
 
- sub haveReadWriteProp{
+ sub haveFunction{
         my ($value) = @_;
-        for my $property (@READWRITEPROPS){
-                if($property eq $value){
-                        return "1";
-                }
-        }
-        return undef;
- }
-
- sub haveProperty{
-        my ($value) = @_;
-        for my $property (@PROPERTIES){
-                if($property eq $value){
+        for my $function (@FUNCTIONS){
+                if($function eq $value){
                         return "1";
                 }
         }
