@@ -26,9 +26,8 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = '0.03';
-our @PROPERTIES = qw( Abort CloseSlit Connect Disconnect FindHome GetAzEl GotoAzEl OpenSlit Park Sync Unpark );
-our @READWRITEPROPS = qw( IsCoupled );
+our $VERSION = '0.11';
+our @PROPERTIES = qw( Abort CloseSlit Connect Disconnect FindHome GetAzEl GotoAzEl OpenSlit Park Sync Unpark slitState lastError );
 
 # Preloaded methods go here.
 
@@ -46,8 +45,6 @@ our @READWRITEPROPS = qw( IsCoupled );
 #    $self->_incr_count();
     return $self;
   }
-#    sub _incr_count { ++$_count }
-#    sub _decr_count { --$_count }
 
  sub AUTOLOAD ($;$) {
     no strict "refs";
@@ -57,15 +54,13 @@ our @READWRITEPROPS = qw( IsCoupled );
     if ($AUTOLOAD =~ /.*::(.*::.*)/) {
       my $method = $1;
       # Let's build the javascript
-#      $newtext = join ',', map{ qq/"$_"/ }@newval;
       $newtext = join ',', map{ /^[0-9.-]*$/ ? $_ : qq/'$_'/ }@newval;
       $method =~ tr/::/./s;
 
       my ($package, $propertyName) = $AUTOLOAD =~ m/^(.+::)(.+)$/;
       if(haveProperty($propertyName)){
         $js .= $method . "(" . $newtext . ");\r\n";
-      } elsif(haveReadWriteProp($propertyName) and length($newtext) ){
-
+      } elsif(length($propertyName) and length($newtext) ){
         $js .= $method . ' = ' . $newtext . ";\r\n";
       } else {
         $js .= $method . ";\r\n";
@@ -76,16 +71,6 @@ our @READWRITEPROPS = qw( IsCoupled );
     die "No such method: $AUTOLOAD";
  }
 
- sub haveReadWriteProp{
-        my ($value) = @_;
-        for my $property (@READWRITEPROPS){
-                if($property eq $value){
-                        return "1";
-                }
-        }
-        return undef;
- }
-
  sub haveProperty{
         my ($value) = @_;
         for my $property (@PROPERTIES){
