@@ -26,9 +26,8 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.11';
 our @PROPERTIES = qw( Property setProperty Name Fill );
-our @READWRITEPROPS = qw(  );
 
 # Preloaded methods go here.
 
@@ -46,8 +45,6 @@ our @READWRITEPROPS = qw(  );
 #    $self->_incr_count();
     return $self;
   }
-#    sub _incr_count { ++$_count }
-#    sub _decr_count { --$_count }
 
  sub AUTOLOAD ($;$) {
     no strict "refs";
@@ -64,8 +61,7 @@ our @READWRITEPROPS = qw(  );
       my ($package, $propertyName) = $AUTOLOAD =~ m/^(.+::)(.+)$/;
       if(haveProperty($propertyName)){
         $js .= $method . "(" . $newtext . ");\r\n";
-      } elsif(haveReadWriteProp($propertyName) and length($newtext) ){
-
+      } elsif(length($propertyName) and length($newtext) ){
         $js .= $method . ' = ' . $newtext . ";\r\n";
       } else {
         $js .= $method . ";\r\n";
@@ -76,16 +72,6 @@ our @READWRITEPROPS = qw(  );
     die "No such method: $AUTOLOAD";
  }
 
- sub haveReadWriteProp{
-        my ($value) = @_;
-        for my $property (@READWRITEPROPS){
-                if($property eq $value){
-                        return "1";
-                }
-        }
-        return undef;
- }
-
  sub haveProperty{
         my ($value) = @_;
         for my $property (@PROPERTIES){
